==> deepin-log-viewer_5.8.32.orig.tar.xz: deepin-log-viewer-5.8.32/translations/deepin-log-viewer_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Logboek wissen</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Weet je zeker dat je het logboek wilt wissen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ja</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dagen</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 week</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 maand</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 maanden</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporteren</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporteren</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Melding</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Foutopsporing</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Ingelogd</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Opgestart</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Afgesloten</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zeer kritiek</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Spoor</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>Platte tekst (*.txt);; DOC (*.doc);; XLS (*.xls);; HTML (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Bezig met exporteren…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exporteren voltooid</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Het exporteren is mislukt</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Bestand exporteren</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periode:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Niveau:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Programmalijst:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Soort moment:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Gebruiker:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Actie:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Opstartmoment</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Afsluitmoment</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Inlogmoment</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Foutopsporing</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Melding</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Spoor</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zeer kritiek</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Het logbestand is leeg</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Logboek</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Met Logboek kun je de logbestanden van het systeem bekijken.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum en tijd</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Gebruiker</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Bron</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Actie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Soort moment</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Niveau:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum en tijd:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informatie:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>n.v.t.</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Gebruiker:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum en tijd</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Systeemlog</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernellog</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Opstartlog</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dpkg-log</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>KWin-logboek</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg-log</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Programmalog</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Opstart- en afsluitmoment</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf-logboek</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Logboek wissen</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Weet je zeker dat je het logboek wilt wissen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ja</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dagen</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 week</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 maand</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 maanden</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporteren</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporteren</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Melding</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Foutopsporing</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Ingelogd</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Opgestart</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Afgesloten</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zeer kritiek</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Spoor</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>Platte tekst (*.txt);; DOC (*.doc);; XLS (*.xls);; HTML (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Bezig met exporteren…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exporteren voltooid</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Het exporteren is mislukt</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Bestand exporteren</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periode:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Niveau:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Programmalijst:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Soort moment:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Gebruiker:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Actie:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Opstartmoment</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Afsluitmoment</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Inlogmoment</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Foutopsporing</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritiek</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Melding</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Spoor</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zeer kritiek</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Het logbestand is leeg</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Logboek</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Met Logboek kun je de logbestanden van het systeem bekijken.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum en tijd</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Gebruiker</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Bron</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Actie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Soort moment</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Niveau:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum en tijd:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informatie:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>n.v.t.</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Gebruiker:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum en tijd</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Systeemlog</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernellog</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Opstartlog</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dpkg-log</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>KWin-logboek</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg-log</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Programmalog</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Opstart- en afsluitmoment</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf-logboek</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Periodiek herladen</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sec.</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min.</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Niet herladen</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Alles exporteren</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Systeemlogboeken</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Nu herladen</translation>
    </message>
</context>
</TS>
